@@ -2,13 +2,13 @@ package Template::Liquid::Document;
 { $Template::Liquid::Document::VERSION = 'v1.0.0' }
 require Template::Liquid::Variable;
 require Template::Liquid::Utility;
+use strict;
 #
-
 sub new {
     my ($class, $args) = @_;
-    raise Template::Liquid::ContextError {
-                                       message => 'Missing template argument',
-                                       fatal   => 1
+    raise Template::Liquid::Error {type    => 'Context',
+                                   message => 'Missing template argument',
+                                   fatal   => 1
         }
         if !defined $args->{'template'};
     return
@@ -21,17 +21,14 @@ sub parse {
     my ($class, $args, $tokens);
     (scalar @_ == 3 ? ($class, $args, $tokens) : ($class, $tokens)) = @_;
     my $s = ref $class ? $class : $class->new($args);
+    my %_tags = $s->{template}->tags;
 NODE: while (my $token = shift @{$tokens}) {
-        if ($token =~ qr[^${Template::Liquid::Utility::TagStart}   # {%
-                                (.+?)                              # etc
-                              ${Template::Liquid::Utility::TagEnd} # %}
-                             $]ox
-            )
-        {   my ($tag, $attrs) = (split ' ', $1, 2);
-            my ($package, $call) = $s->{template}{tags}{$tag};
-            if ($package
-                && ($call = $s->{template}{tags}{$tag}->can('new')))
-            {   my $_tag =
+        if ($token =~ $Template::Liquid::Utility::TagMatch) {
+            my ($tag, $attrs) = (split ' ', $1, 2);
+            my $package = $_tags{$tag};
+            my $call = $package ? $package->can('new') : ();
+            if (defined $call) {
+                my $_tag =
                     $call->($package,
                             {template => $s->{template},
                              parent   => $s,
@@ -44,11 +41,11 @@ NODE: while (my $token = shift @{$tokens}) {
                 if ($_tag->conditional_tag) {
                     push @{$_tag->{'blocks'}},
                         Template::Liquid::Block->new(
-                                              {tag_name => $tag,
-                                               attrs    => $attrs,
-                                               template => $_tag->{template},
-                                               parent   => $_tag
-                                              }
+                                            {tag_name => $tag,
+                                             attrs    => $attrs,
+                                             template => $_tag->{template},
+                                             parent   => $_tag
+                                            }
                         );
                     $_tag->parse($tokens);
                     {    # finish previous block
@@ -77,17 +74,14 @@ NODE: while (my $token = shift @{$tokens}) {
                 );
             }
             else {
-                raise Template::Liquid::SyntaxError 'Unknown tag: ' . $token;
+                raise Template::Liquid::Error {
+                                           type    => 'Syntax',
+                                           message => 'Unknown tag: ' . $token
+                };
             }
         }
-        elsif (
-            $token =~ qr[^
-                    ${Template::Liquid::Utility::VariableStart} # {{
-                        (.+?)                           #  stuff + filters?
-                    ${Template::Liquid::Utility::VariableEnd}   # }}
-                $]ox
-            )
-        {   my ($variable, $filters) = split qr[\s*\|\s*]o, $1, 2;
+        elsif ($token =~ $Template::Liquid::Utility::VarMatch) {
+            my ($variable, $filters) = split qr[\s*\|\s*]o, $1, 2;
             my @filters;
             for my $filter (split $Template::Liquid::Utility::FilterSeparator,
                             $filters || '')
@@ -106,12 +100,13 @@ NODE: while (my $token = shift @{$tokens}) {
                 push @filters, [$filter, \@args];
             }
             push @{$s->{'nodelist'}},
-                Template::Liquid::Variable->new({template => $s->{template},
-                                                 parent   => $s,
-                                                 markup   => $token,
-                                                 variable => $variable,
-                                                 filters  => \@filters
-                                                }
+                Template::Liquid::Variable->new(
+                                               {template => $s->{template},
+                                                parent   => $s,
+                                                markup   => $token,
+                                                variable => $variable,
+                                                filters  => \@filters
+                                               }
                 );
         }
         else {
@@ -167,4 +162,3 @@ http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
 clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 
 =cut
-
