@@ -34,6 +34,15 @@ our $VariableParser = qr[^
                             $]ox;
 our $VariableFilterArgumentParser
     = qr[\s*,\s*(?=(?:[^\']*\'[^\']*\')*(?![^\']*\'))]o;
+our $TagMatch = qr[^${Template::Liquid::Utility::TagStart}   # {%
+                                (.+?)                              # etc
+                              ${Template::Liquid::Utility::TagEnd} # %}
+                             $]ox;
+our $VarMatch = qr[^
+                    ${Template::Liquid::Utility::VariableStart} # {{
+                        (.+?)                           #  stuff + filters?
+                    ${Template::Liquid::Utility::VariableEnd}   # }}
+                $]ox;
 
 sub tokenize {
     map { $_ ? $_ : () } split $TemplateParser, shift || '';
